# Note: this file has been initially generated by Module::Build::Convert 0.50

use 5.008;
use strict;
use warnings;

use Module::Build;

my $build = Module::Build->new
   (
    module_name => 'App::SimpleScan',
    dist_author => 'Joe McMahon <mcmahon@cpan.org>',
    dist_version_from => 'lib/App/SimpleScan.pm',
    requires => {
                  'Class::Accessor' => 0,
                  'Clone' => '0.20',
                  'Encode' => 0,
                  'Getopt::Long' => 0,
                  'Graph' => '0.65',
                  'IO::ScalarArray' => '2.110',
                  'Regexp::Common' => 0,
                  'Scalar::Util' => 0,
                  'Sub::Installer' => 0,
                  'TAP::Parser' => 0,
                  'Test::Differences' => 0,
                  'Test::More' => 0,
                  'Test::WWW::Simple' => '0.41',
                  'WWW::Mechanize' => '1.16',
                  'WWW::Mechanize::Pluggable' => '0.09',
                },
    add_to_cleanup => [
                        'App-SimpleScan-*',
                      ],
    license => 'unknown',
    create_readme => 1,
    create_makefile_pl => 'traditional',
   );

$build->create_build_script;
